@@ -50,47 +50,12 @@ test_that("param_set", {
   inst = MAKE_INST_1D()
   surrogate = SurrogateLearner$new(learner = REGR_FEATURELESS, archive = inst$archive)
   expect_r6(surrogate$param_set, "ParamSet")
-  expect_setequal(surrogate$param_set$ids(), c("assert_insample_perf", "perf_measure", "perf_threshold", "catch_errors", "impute_method"))
-  expect_equal(surrogate$param_set$class[["assert_insample_perf"]], "ParamLgl")
-  expect_equal(surrogate$param_set$class[["perf_measure"]], "ParamUty")
-  expect_equal(surrogate$param_set$class[["perf_threshold"]], "ParamDbl")
+  expect_setequal(surrogate$param_set$ids(), c("catch_errors", "impute_method"))
   expect_equal(surrogate$param_set$class[["catch_errors"]], "ParamLgl")
   expect_equal(surrogate$param_set$class[["impute_method"]], "ParamFct")
   expect_error({surrogate$param_set = list()}, regexp = "param_set is read-only.")
 })
 
-test_that("insample_perf", {
-  skip_if_not_installed("mlr3learners")
-  skip_if_not_installed("DiceKriging")
-  skip_if_not_installed("rgenoud")
-  inst = MAKE_INST_1D()
-  design = MAKE_DESIGN(inst)
-  inst$eval_batch(design)
-
-  surrogate = SurrogateLearner$new(learner = REGR_KM_DETERM, archive = inst$archive)
-  expect_error({surrogate$insample_perf = 0}, regexp = "insample_perf is read-only.")
-  expect_error({surrogate$assert_insample_perf = 0}, regexp = "assert_insample_perf is read-only.")
-
-  surrogate$update()
-  expect_equal(surrogate$insample_perf, NaN)
-
-  surrogate$param_set$values$assert_insample_perf = TRUE
-  surrogate$param_set$values$perf_threshold = 0
-  surrogate$param_set$values$perf_measure = mlr_measures$get("regr.rsq")
-  surrogate$update()
-  expect_number(surrogate$insample_perf, lower = -Inf, upper = 1)
-  expect_equal(names(surrogate$insample_perf), surrogate$param_set$values$perf_measure$id)
-
-  surrogate_constant = SurrogateLearner$new(learner = REGR_FEATURELESS, archive = inst$archive)
-  surrogate_constant$param_set$values$assert_insample_perf = TRUE
-  surrogate_constant$param_set$values$perf_threshold = 0.5
-  surrogate$param_set$values$perf_measure = mlr_measures$get("regr.rsq")
-  expect_error(surrogate_constant$update(), regexp = "Current insample performance of the Surrogate Model does not meet the performance threshold")
-  expect_number(surrogate_constant$insample_perf, lower = -Inf, upper = 1)
-  expect_true(surrogate_constant$insample_perf <= 1e-3)
-  expect_equal(names(surrogate_constant$insample_perf), surrogate$param_set$values$perf_measure$id)
-})
-
 test_that("deep clone", {
   inst = MAKE_INST_1D()
   surrogate1 = SurrogateLearner$new(learner = REGR_FEATURELESS, archive = inst$archive)
