@@ -8,12 +8,13 @@ test_that("TunerAsyncMbo works", {
     minsplit  = to_tune(2L, 128L),
     cp        = to_tune(1e-04, 1e-1))
 
-  rush::rush_plan(n_workers = 4L)
+  mirai::daemons(4L)
+  rush::rush_plan(n_workers = 4L, worker_type = "remote")
   instance = ti_async(
     task = tsk("pima"),
     learner = learner,
     resampling = rsmp("cv", folds = 3L),
-    measure = msr("classif.ce"),
+    measures = msr("classif.ce"),
     terminator = trm("evals", n_evals = 20L),
     store_benchmark_result = FALSE
   )
